@@ -4,8 +4,9 @@ use warnings;
 
 package Error::Hierarchy::Container;
 BEGIN {
-  $Error::Hierarchy::Container::VERSION = '1.100980';
+  $Error::Hierarchy::Container::VERSION = '1.101690';
 }
+
 # ABSTRACT: Container for hierarchical exceptions
 use Data::Miscellany 'set_push';
 
@@ -33,6 +34,22 @@ sub delete_by_uuid {
     @uuid{@uuid} = ();
     $self->items(grep { !exists $uuid{$_} } $self->items);
 }
+
+sub delete_duplicate_exceptions {
+    my $self = shift;
+    my @items;
+    my %seen;
+    for my $exception ($self->items) {
+        my %properties = $exception->properties_as_hash;
+        $properties{__package} = ref $exception;
+        my $signature =
+          join ';' => map { $_ => $properties{$_} } sort keys %properties;
+        next if $seen{$signature}++;
+        push @items => $exception;
+    }
+    $self->items(@items);
+    $self;
+}
 1;
 
 
@@ -45,7 +62,7 @@ Error::Hierarchy::Container - Container for hierarchical exceptions
 
 =head1 VERSION
 
-version 1.100980
+version 1.101690
 
 =head1 SYNOPSIS
 
@@ -79,6 +96,12 @@ yourself.
 Takes a list of uuid values and deletes all those exceptions from the
 container whose uuid appears in the given list.
 
+=head2 delete_duplicate_exceptions
+
+Deletes duplicate exceptions. Two exceptions are considered to be the same if
+they are of the same class and have the same properties, as defined by the
+exception's C<properties_as_hash()> method.
+
 =head1 INSTALLATION
 
 See perlmodinstall for information and options on installing Perl modules.
@@ -88,7 +111,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Error-Hierarchy>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
@@ -97,6 +120,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Error-Hierarchy/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Error-Hierarchy/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
